pub struct KeypairBytes {
pub secret_key: [u8; 32],
pub public_key: Option<PublicKeyBytes>,
}Expand description
Ed25519 keypair serialized as bytes.
This type is primarily useful for decoding/encoding PKCS#8 private key files (either DER or PEM) encoded using the following traits:
DecodePrivateKey: decode DER or PEM encoded PKCS#8 private key.EncodePrivateKey: encode DER or PEM encoded PKCS#8 private key.
PKCS#8 private key files encoded with PEM begin with:
-----BEGIN PRIVATE KEY-----Note that this type operates on raw bytes and performs no validation that keys represent valid Ed25519 field elements.
Fields
secret_key: [u8; 32]Ed25519 secret key.
Little endian serialization of an element of the Curve25519 scalar field, prior to “clamping” (i.e. setting/clearing bits to ensure the scalar is actually a valid field element)
public_key: Option<PublicKeyBytes>Ed25519 public key (if available).
Compressed Edwards-y encoded curve point.
Implementations
Sourceimpl KeypairBytes
impl KeypairBytes
Sourcepub fn from_bytes(bytes: &[u8; 64]) -> Self
pub fn from_bytes(bytes: &[u8; 64]) -> Self
Parse raw keypair from a 64-byte input.